@@ -5,7 +5,7 @@ use strict;
 use Carp ();
 use Exporter;
 
-our $VERSION = '1.33';
+our $VERSION = '1.34';
 
 use parent 'Exporter';
 
@@ -160,9 +160,8 @@ sub timegm {
 
     my $days = _daygm( undef, undef, undef, $mday, $month, $year );
 
-    unless ( $Options{no_range_check} or abs($days) < $MaxDay ) {
-        my $msg = q{};
-        $msg .= "Day too big - $days > $MaxDay\n" if $days > $MaxDay;
+    if ( abs($days) > $MaxDay && !$Options{no_range_check} ) {
+        my $msg = "Day too big - abs($days) > $MaxDay\n";
 
         $year += 1900;
         $msg
@@ -279,7 +278,7 @@ Time::Local - Efficiently compute time from local and GMT time
 
 =head1 VERSION
 
-version 1.33
+version 1.34
 
 =head1 SYNOPSIS
 
